@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2019 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,26 +10,18 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
+"""PyAMS_file.include module
+
+This module is used for Pyramid integration
+"""
+
 __docformat__ = 'restructuredtext'
 
 
-# import standard library
-
-# import interfaces
-
-# import packages
-
-
 def include_package(config):
-    """Pyramid include"""
+    """Pyramid package include"""
 
-    # load registry components
-    try:
-        import pyams_zmi
-    except ImportError:
-        config.scan(ignore='pyams_file.zmi')
-    else:
-        config.scan()
+    # add translations
+    config.add_translation_dirs('pyams_file:locales')
 
-    if hasattr(config, 'load_zcml'):
-        config.load_zcml('configure.zcml')
+    config.scan()
